pub struct ExecutionState {
pub side: i32,
pub current_round: u32,
pub total_rounds: u32,
pub round_fills: Vec<RoundFillState>,
pub total_fill_rate: f64,
pub trigger_spread: i64,
}Expand description
실행 상태
Fields
side: i32실행 방향
current_round: u32현재 라운드 (1-based)
total_rounds: u32총 라운드 수
round_fills: Vec<RoundFillState>라운드별 체결 상태
total_fill_rate: f64전체 체결률
trigger_spread: i64트리거 시점 스프레드
Implementations
Sourceimpl ExecutionState
impl ExecutionState
Sourcepub fn side(&self) -> ArbitrageSide
pub fn side(&self) -> ArbitrageSide
Returns the enum value of side, or the default if the field is set to an invalid enum value.
Sourcepub fn set_side(&mut self, value: ArbitrageSide)
pub fn set_side(&mut self, value: ArbitrageSide)
Sets side to the provided enum value.