pub struct PriceUpdateEvent {
pub basket_a_value: i64,
pub basket_b_value: i64,
pub spread: i64,
pub spread_bps: f64,
}Expand description
가격 업데이트 이벤트
Fields
basket_a_value: i64basket_b_value: i64spread: i64spread_bps: f64Trait Implementations
Sourceimpl Clone for PriceUpdateEvent
impl Clone for PriceUpdateEvent
Sourcefn clone(&self) -> PriceUpdateEvent
fn clone(&self) -> PriceUpdateEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PriceUpdateEvent
Sourceimpl Debug for PriceUpdateEvent
impl Debug for PriceUpdateEvent
Sourceimpl Default for PriceUpdateEvent
impl Default for PriceUpdateEvent
impl<'de> Deserialize<'de> for PriceUpdateEvent
impl<'de> Deserialize<'de> for PriceUpdateEvent
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for PriceUpdateEvent
impl Message for PriceUpdateEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PriceUpdateEvent
impl PartialEq for PriceUpdateEvent
Sourcefn eq(&self, other: &PriceUpdateEvent) -> bool
fn eq(&self, other: &PriceUpdateEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for PriceUpdateEvent
impl Serialize for PriceUpdateEvent
impl StructuralPartialEq for PriceUpdateEvent