pub struct StateChangedEvent {
pub old_state: i32,
pub new_state: i32,
}Expand description
상태 변경 이벤트
Fields
old_state: i32new_state: i32Implementations
Sourceimpl StateChangedEvent
impl StateChangedEvent
Sourcepub fn old_state(&self) -> ArbitrageState
pub fn old_state(&self) -> ArbitrageState
Returns the enum value of old_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_old_state(&mut self, value: ArbitrageState)
pub fn set_old_state(&mut self, value: ArbitrageState)
Sets old_state to the provided enum value.
Sourcepub fn new_state(&self) -> ArbitrageState
pub fn new_state(&self) -> ArbitrageState
Returns the enum value of new_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_new_state(&mut self, value: ArbitrageState)
pub fn set_new_state(&mut self, value: ArbitrageState)
Sets new_state to the provided enum value.