#[repr(i32)]pub enum OrderConditionType {
Unspecified = 0,
Fas = 1,
Fak = 2,
Fok = 3,
}Expand description
호가조건코드 (KRX) 주문 체결 방식을 지정하는 조건
Variants
Unspecified = 0
미지정 (기본값: FAS로 처리, 하위 호환)
Fas = 1
Fill-and-Store: 체결 후 잔량은 호가창에 유지 (일반 지정가) — KRX code “0”
Fak = 2
Fill-and-Kill (IOC): 체결 후 잔량 즉시 취소 — KRX code “3”
Fok = 3
Fill-or-Kill: 전량 체결 아니면 전량 취소 — KRX code “4”
Implementations
Sourceimpl OrderConditionType
impl OrderConditionType
Sourcepub fn from_i32(value: i32) -> Option<OrderConditionType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<OrderConditionType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a OrderConditionType, or None if value is not a valid variant.
Sourceimpl OrderConditionType
impl OrderConditionType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.