#[repr(i32)]pub enum RelativePriceSource {
Unspecified = 0,
BestMake = 1,
BestTake = 2,
}Expand description
참조 가격 소스 — entry(주문) 의 side 기준 자기/상대 호가. 절대 위치(Bid1/Ask1/MidPrice 등)를 나타내는 kdo.v1.basket.PriceSource 와 달리 side 에 상대적이므로 혼동 방지를 위해 이름을 RelativePriceSource 로 구분한다. kdo.v1.pair.PriceSource 와 동일한 의미.
Variants
Unspecified = 0
BestMake = 1
자기호가 (entry.side 와 같은 방향의 1호가). Bid 주문 → bid1, Ask 주문 → ask1.
BestTake = 2
상대호가 (entry.side 반대 방향의 1호가). Bid 주문 → ask1, Ask 주문 → bid1.
Implementations
Sourceimpl RelativePriceSource
impl RelativePriceSource
Sourcepub fn from_i32(value: i32) -> Option<RelativePriceSource>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<RelativePriceSource>
Use the TryFrom<i32> implementation instead
Converts an i32 to a RelativePriceSource, or None if value is not a valid variant.
Sourceimpl RelativePriceSource
impl RelativePriceSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.