#[repr(i32)]pub enum SessionId {
Show 17 variants
Unspecified = 0,
Previous = 1,
Connected = 2,
OpeningOnePrice = 3,
OnePrice = 4,
ClosingOnePrice = 5,
ViOnePrice = 6,
ViOpeningOnePrice = 7,
ViClosingOnePrice = 8,
UnitTrade = 9,
PostMarket = 10,
AuctionBid = 11,
AuctionAsk = 12,
Suspended = 13,
Shutdown = 14,
Closed = 15,
Etc = 16,
}Expand description
KRX 세부 세션 ID (16-state)
Variants
Unspecified = 0
Previous = 1
장개시전
Connected = 2
연결됨
OpeningOnePrice = 3
시가단일가
OnePrice = 4
단일가
ClosingOnePrice = 5
종가단일가
ViOnePrice = 6
VI장중단일가
ViOpeningOnePrice = 7
VI시가단일가
ViClosingOnePrice = 8
VI종가단일가
UnitTrade = 9
단위매매
PostMarket = 10
장종료후호가접수
AuctionBid = 11
경매매수호가 접수 세션
AuctionAsk = 12
경매매도호가 접수 세션
Suspended = 13
거래정지
Shutdown = 14
셧다운
Closed = 15
장마감
Etc = 16
기타
Implementations
Sourceimpl SessionId
impl SessionId
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.