#[repr(i32)]pub enum ProgramTradingType {
Unspecified = 0,
IndexArbitrage = 1,
StockArbitrage = 2,
EtfLpHedge = 3,
}Expand description
프로그램매매 구분코드
Variants
Implementations
Sourceimpl ProgramTradingType
impl ProgramTradingType
Sourcepub fn from_i32(value: i32) -> Option<ProgramTradingType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ProgramTradingType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ProgramTradingType, or None if value is not a valid variant.
Sourceimpl ProgramTradingType
impl ProgramTradingType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.