pub struct Future {Show 23 fields
pub name: String,
pub code: String,
pub symbol: String,
pub market_name: String,
pub market_type: i32,
pub max_quantity_per_order: i64,
pub tick_size: f64,
pub prev_price: f64,
pub base_price: f64,
pub max_price: f64,
pub min_price: f64,
pub unit: f64,
pub multiple: f64,
pub tradable: bool,
pub future_option_type: i32,
pub last_tradable_date: String,
pub maturity_date: String,
pub underlying_code: String,
pub underlying_prev_price: f64,
pub remaining_days: f64,
pub last_tradable_day: bool,
pub cd_rate: f64,
pub final_settlement_date: String,
}Expand description
선물/옵션 종목 정보
Fields
name: String리소스 이름 (futures/{code})
code: String종목 코드
symbol: String심볼
market_name: String종목명
market_type: i32시장 유형
max_quantity_per_order: i641회 최대 주문 수량
tick_size: f64틱 크기
prev_price: f64전일 종가
base_price: f64기준가
max_price: f64상한가
min_price: f64하한가
unit: f64거래 단위
multiple: f64거래 승수
tradable: bool거래 가능 여부
future_option_type: i32선물/옵션 유형
last_tradable_date: String최종 거래일 (YYYY-MM-DD)
maturity_date: String만기일 (YYYY-MM-DD)
underlying_code: String기초자산 코드
underlying_prev_price: f64기초자산 전일 종가
remaining_days: f64잔존일수
last_tradable_day: bool최종 거래일 여부
cd_rate: f64CD 금리
final_settlement_date: String최종 결제일 (YYYY-MM-DD)
Implementations
Sourceimpl Future
impl Future
Sourcepub fn market_type(&self) -> MarketType
pub fn market_type(&self) -> MarketType
Returns the enum value of market_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_market_type(&mut self, value: MarketType)
pub fn set_market_type(&mut self, value: MarketType)
Sets market_type to the provided enum value.
Sourcepub fn future_option_type(&self) -> FutureOptionType
pub fn future_option_type(&self) -> FutureOptionType
Returns the enum value of future_option_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_future_option_type(&mut self, value: FutureOptionType)
pub fn set_future_option_type(&mut self, value: FutureOptionType)
Sets future_option_type to the provided enum value.