#[repr(i32)]pub enum DbcrClsCode {
Unspecified = 0,
Lend = 1,
Borrow = 2,
}Expand description
대차구분코드 (DBCR_CLS_CODE) obfnp_loan_021r 조회 필터: 1=대여, 2=차입, 빈값=전체
Variants
Implementations
Sourceimpl DbcrClsCode
impl DbcrClsCode
Sourceimpl DbcrClsCode
impl DbcrClsCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.