#[repr(i32)]pub enum PositionAdjustmentStrategy {
Unspecified = 0,
Avoidance = 1,
Turnover = 2,
All = 10,
}Expand description
순매매량 기반 조정 전략
Variants
Unspecified = 0
Avoidance = 1
회피: 순매수 과다 시 매수offset 증가 (덜 공격적으로 매수)
Turnover = 2
매매회전: 순매수 과다 시 매도offset 감소 (더 공격적으로 매도)
All = 10
모두 적용: 순매수 과다 시 매수offset 증가 및 매도offset 감소
Implementations
Sourceimpl PositionAdjustmentStrategy
impl PositionAdjustmentStrategy
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of PositionAdjustmentStrategy.
Sourcepub fn from_i32(value: i32) -> Option<PositionAdjustmentStrategy>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<PositionAdjustmentStrategy>
Use the TryFrom<i32> implementation instead
Converts an i32 to a PositionAdjustmentStrategy, or None if value is not a valid variant.
Sourceimpl PositionAdjustmentStrategy
impl PositionAdjustmentStrategy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.