pub struct Notification {Show 15 fields
pub name: String,
pub user: String,
pub portfolio: Option<String>,
pub id: u64,
pub type: i32,
pub action: Option<NotificationAction>,
pub state: i32,
pub title: String,
pub body: String,
pub metadata: HashMap<String, String>,
pub navigation_url: Option<String>,
pub create_time: Option<Timestamp>,
pub expire_time: Option<Timestamp>,
pub acknowledge_time: Option<Timestamp>,
pub symbol: Option<String>,
}Expand description
Notification resource
Fields
name: StringThe resource name of the Notification. Format: notifications/{notification_id}
user: StringThe resource name of User. Format: users/{user_id}
portfolio: Option<String>The resource name of Portfolio (optional). Format: portfolios/{id}
id: u64The id of Notification.
type: i32Notification type
action: Option<NotificationAction>Action to perform when clicked
state: i32Current state
title: StringNotification title
body: StringNotification body
metadata: HashMap<String, String>Additional metadata
Pre-computed navigation URL (convenience field) e.g., “/lp/A252670”
create_time: Option<Timestamp>Created timestamp
expire_time: Option<Timestamp>Expiration timestamp (if applicable)
acknowledge_time: Option<Timestamp>Acknowledged timestamp
symbol: Option<String>관련 심볼 (예: ETF 종목코드 KR7252670005). LP/주문 관련 알림(EtfLpEvent, QuickOrderError)이 채움. 심볼 무관 알림(System/Custom 등)은 비어있음.
Implementations
Sourceimpl Notification
impl Notification
Sourcepub fn portfolio(&self) -> &str
pub fn portfolio(&self) -> &str
Returns the value of portfolio, or the default value if portfolio is unset.
Sourcepub fn type(&self) -> NotificationType
pub fn type(&self) -> NotificationType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: NotificationType)
pub fn set_type(&mut self, value: NotificationType)
Sets type to the provided enum value.
Sourcepub fn state(&self) -> NotificationState
pub fn state(&self) -> NotificationState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: NotificationState)
pub fn set_state(&mut self, value: NotificationState)
Sets state to the provided enum value.
Returns the value of navigation_url, or the default value if navigation_url is unset.