pub struct SubmitOrderResponse {
pub order_id: u64,
pub status: i32,
pub message: String,
}Fields
order_id: u64주문 ID
status: i32주문 상태
message: String결과 메시지
Implementations
Sourceimpl SubmitOrderResponse
impl SubmitOrderResponse
Sourcepub fn status(&self) -> OrderStatus
pub fn status(&self) -> OrderStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: OrderStatus)
pub fn set_status(&mut self, value: OrderStatus)
Sets status to the provided enum value.