#[repr(i32)]pub enum MakerTakerEventType {
Unspecified = 0,
MakerSubmitted = 1,
MakerAmended = 2,
MakerFilled = 3,
MakerRejected = 4,
MakerCancelled = 5,
TakerSubmitted = 6,
TakerFilled = 7,
TakerRejected = 8,
}Expand description
Maker-Taker 이벤트 유형
Variants
Unspecified = 0
MakerSubmitted = 1
maker 신규 발주 (FEP submit 직후)
MakerAmended = 2
maker 정정 (가격/수량 변경)
MakerFilled = 3
maker 부분/완전 체결
MakerRejected = 4
maker 주문 reject
MakerCancelled = 5
maker 주문 거래소 auto-cancel
TakerSubmitted = 6
taker 헷지 주문 발주
TakerFilled = 7
taker 헷지 체결
TakerRejected = 8
taker 헷지 reject (수동 개입 필요)
Implementations
Sourceimpl MakerTakerEventType
impl MakerTakerEventType
Sourcepub fn from_i32(value: i32) -> Option<MakerTakerEventType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<MakerTakerEventType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a MakerTakerEventType, or None if value is not a valid variant.
Sourceimpl MakerTakerEventType
impl MakerTakerEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.