#[repr(i32)]pub enum PriceSource {
Unspecified = 0,
MidPrice = 1,
LastPrice = 2,
BestBid = 3,
BestAsk = 4,
}Expand description
참조 가격 소스
Variants
Unspecified = 0
MidPrice = 1
중간가 (Bid1 + Ask1) / 2
LastPrice = 2
직전 체결가
BestBid = 3
최우선 매수호가
BestAsk = 4
최우선 매도호가
Implementations
Sourceimpl PriceSource
impl PriceSource
Sourceimpl PriceSource
impl PriceSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.