#[repr(i32)]pub enum SpreadDirection {
Unspecified = 0,
BaseHigh = 1,
CounterHigh = 2,
Both = 3,
}Expand description
스프레드 방향 (어느 쪽이 비쌀 때 트리거할지)
Variants
Implementations
Sourceimpl SpreadDirection
impl SpreadDirection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.