pub struct ListUsersResponse {
pub users: Vec<User>,
pub next_page_token: String,
}Expand description
ListUsersResponse (– api-linter: core::0158::response-next-page-token-field=disabled aip.dev/not-precedent: We need to do this because reasons. –)
Fields
users: Vec<User>The list of rows that matched the query.
next_page_token: StringPagination token used to retrieve the next page of results.
Pass the content of this string as the page_token attribute of
the next request. next_page_token is not returned for the last
page.