pub struct BasketManagerDetail {Show 51 fields
pub code: String,
pub name: String,
pub start_at: String,
pub stop_at: String,
pub is_long: bool,
pub active: bool,
pub current_round: i64,
pub total_rounds: i64,
pub done_rounds: i64,
pub minimum_filled_ratio: f64,
pub minimum_interval: f64,
pub trigger_basis: f64,
pub index_code: String,
pub index_name: String,
pub basis_condition: String,
pub basis_type: String,
pub basis_price_type: String,
pub items: Vec<BasketManagerDetailItem>,
pub user_code: String,
pub public: bool,
pub remaining_turns: i64,
pub ui_group: String,
pub check_all_sellable: bool,
pub long_product_type: String,
pub short_product_type: String,
pub short_quantity: i64,
pub long_quantity: i64,
pub short_products: i64,
pub long_products: i64,
pub short_sellable: bool,
pub apply_slippage: bool,
pub pause_round: i64,
pub created_at: String,
pub fundcode: String,
pub etf_unfilled_limit: f64,
pub grace_the_money: f64,
pub regard_smp_as_traded: bool,
pub execution_threshold: f64,
pub starter_limit_rounds: i64,
pub id_number: String,
pub check_all_connected: bool,
pub future_maturity_no: String,
pub auto_launch: bool,
pub launch_at: String,
pub start_amend_at: String,
pub launch_price_percent: f64,
pub participation_limit_percent: f64,
pub launched: bool,
pub custom_product_code: String,
pub custom_product_ratio: f64,
pub exchange: String,
}Fields
code: Stringname: Stringstart_at: Stringstop_at: Stringis_long: boolactive: boolcurrent_round: i64total_rounds: i64done_rounds: i64minimum_filled_ratio: f64minimum_interval: f64trigger_basis: f64index_code: Stringindex_name: Stringbasis_condition: Stringbasis_type: Stringbasis_price_type: Stringitems: Vec<BasketManagerDetailItem>user_code: Stringpublic: boolremaining_turns: i64ui_group: Stringcheck_all_sellable: boollong_product_type: Stringshort_product_type: Stringshort_quantity: i64long_quantity: i64short_products: i64long_products: i64short_sellable: boolapply_slippage: boolpause_round: i64created_at: Stringfundcode: Stringetf_unfilled_limit: f64grace_the_money: f64regard_smp_as_traded: boolexecution_threshold: f64starter_limit_rounds: i64id_number: Stringcheck_all_connected: boolfuture_maturity_no: Stringauto_launch: bool종가자동발주
launch_at: String종가자동발주시간
start_amend_at: String종가관여조정시작시각
launch_price_percent: f64종가자동발주가격%
participation_limit_percent: f64종가관여최대%
launched: bool종가발주완료
custom_product_code: Stringcustom_product_ratio: f64exchange: StringTrait Implementations
Sourceimpl Clone for BasketManagerDetail
impl Clone for BasketManagerDetail
Sourcefn clone(&self) -> BasketManagerDetail
fn clone(&self) -> BasketManagerDetail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BasketManagerDetail
impl Debug for BasketManagerDetail
Sourceimpl Default for BasketManagerDetail
impl Default for BasketManagerDetail
impl<'de> Deserialize<'de> for BasketManagerDetail
impl<'de> Deserialize<'de> for BasketManagerDetail
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for BasketManagerDetail
impl Message for BasketManagerDetail
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BasketManagerDetail
impl PartialEq for BasketManagerDetail
Sourcefn eq(&self, other: &BasketManagerDetail) -> bool
fn eq(&self, other: &BasketManagerDetail) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for BasketManagerDetail
impl Serialize for BasketManagerDetail
impl StructuralPartialEq for BasketManagerDetail